# Table of Contents

- [application-rationalization](<./application-rationalization.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Application Rationalization](<./Application-Rationalization.md>)
  - [Overview](<./Application-Rationalization/Overview.md>)
  - [What is Application Rationalization?](<./Application-Rationalization/What-is-Application-Rationalization.md>)
  - [Why Is Application Rationalization Relevant?](<./Application-Rationalization/Why-Is-Application-Rationalization-Relevant.md>)
  - [What Are the Benefits of Application Rationalization?](<./Application-Rationalization/What-Are-the-Benefits-of-Application-Rationalization.md>)
  - [Before You Start](<./Application-Rationalization/Before-You-Start.md>)
  - [Step-by-Step Guide](<./Application-Rationalization/Step-by-Step-Guide.md>)
  - [Related Resources](<./Application-Rationalization/Related-Resources.md>)
